@@ -11,5 +11,6 @@ from ._adda import ADDA
 from ._deepcoral import DeepCORAL
 from ._mcd import MCD
 from ._mdd import MDD
+from ._wdgrl import WDGRL
 
-__all__ = ["FE", "CORAL", "DeepCORAL", "ADDA", "DANN", "mSDA", "MCD", "MDD", "BaseDeepFeature"]
+__all__ = ["FE", "CORAL", "DeepCORAL", "ADDA", "DANN", "mSDA", "MCD", "MDD", "WDGRL", "BaseDeepFeature"]
