@@ -270,7 +270,7 @@ estimators = [
     Ridge(alpha=10, fit_intercept=False, tol=0.1),
     DecisionTreeClassifier(max_depth=10),
     AdaBoostRegressor(Ridge(alpha=0.01)),
-    TransformedTargetRegressor(Ridge(alpha=25), StandardScaler()),
+    TransformedTargetRegressor(regressor=Ridge(alpha=25), transformer=StandardScaler()),
     MultiOutputRegressor(Ridge(alpha=0.3)),
     make_pipeline(StandardScaler(), Ridge(alpha=0.2)),
     KerasClassifier(_get_model_Sequential, input_shape=(1,)),
@@ -433,6 +433,9 @@ def test_gradienthandler(lambda_):
         gradient = tape.gradient(grad_handler(inputs),
                                  inputs)
     assert np.all(gradient == lambda_ * np.ones(3))
+    config = grad_handler.get_config()
+    assert config['lambda_init'] == lambda_
+    
 
 
 def test_make_classification_da():
@@ -458,4 +461,4 @@ def test_make_regression_da():
     assert Xs.shape == (1000, 10)
     assert len(ys) == 1000
     assert Xt.shape == (1000, 10)
-    assert len(yt) == 1000
\ No newline at end of file
+    assert len(yt) == 1000
